@@ -169,7 +169,7 @@ void static_analysis_baset::output(
   forall_goto_program_instructions(i_it, goto_program)
   {
     out << "**** " << i_it->location_number << " "
-        << i_it->location << "\n";
+        << i_it->source_location << "\n";
 
     get_state(i_it).output(ns, out);
     out << "\n";
