@@ -15,32 +15,6 @@ ansi_c_parsert ansi_c_parser;
 
 /*******************************************************************\
 
-Function: ansi_c_parsert::scopet::print
-
-  Inputs:
-
- Outputs:
-
- Purpose:
-
-\*******************************************************************/
-
-void ansi_c_parsert::scopet::print(std::ostream &out) const
-{
-  out << "Prefix: " << prefix << std::endl;
-
-  for(scopet::name_mapt::const_iterator n_it=name_map.begin();
-      n_it!=name_map.end();
-      n_it++)
-  {
-    out << "  ID: " << n_it->first
-        << " CLASS: " << n_it->second.id_class
-        << std::endl;
-  }
-}
-
-/*******************************************************************\
-
 Function: ansi_c_parsert::lookup
 
   Inputs:
@@ -90,6 +64,33 @@ ansi_c_id_classt ansi_c_parsert::lookup(
 
 /*******************************************************************\
 
+Function: ansi_c_parsert::add_tag_with_body
+
+  Inputs:
+
+ Outputs:
+
+ Purpose:
+
+\*******************************************************************/
+
+void ansi_c_parsert::add_tag_with_body(irept &tag)
+{
+  const std::string scope_name=
+    "tag-"+tag.get_string(ID_C_base_name);
+
+  irep_idt identifier=current_scope().prefix+scope_name;
+  
+  if(identifier!=tag.get(ID_identifier))
+  {
+    // re-defined in a deeper scope
+    current_scope().name_map[scope_name].id_class=ANSI_C_TAG;
+    tag.set(ID_identifier, identifier);
+  }
+}
+
+/*******************************************************************\
+
 Function: yyansi_cerror
 
   Inputs:
