@@ -545,7 +545,7 @@ void c_typecheck_baset::typecheck_expr_builtin_offsetof(exprt &expr)
 {
   // these need not be constant, due to array indices!
 
-  if(expr.operands().size()!=0)
+  if(!expr.operands().empty())
   {
     err_location(expr);
     throw "builtin_offsetof expects no operands";
@@ -763,7 +763,7 @@ void c_typecheck_baset::typecheck_expr_operands(exprt &expr)
     
     code_declt decl;
     decl.add_source_location()=declaration.source_location();
-    decl.symbol()=symbol_expr(symbol);
+    decl.symbol()=symbol.symbol_expr();
 
     expr.op0()=decl;    
 
@@ -982,7 +982,7 @@ void c_typecheck_baset::typecheck_expr_sizeof(exprt &expr)
 {
   typet type;
 
-  if(expr.operands().size()==0)
+  if(expr.operands().empty())
   {
     type.swap(static_cast<typet &>(expr.add(ID_type_arg)));
     typecheck_type(type);
@@ -1243,8 +1243,8 @@ void c_typecheck_baset::typecheck_expr_typecast(exprt &expr)
     // an integer/float of the same size
     if((expr_type.id()==ID_signedbv ||
         expr_type.id()==ID_unsignedbv) &&
-       pointer_offset_size(*this, expr_type)==
-       pointer_offset_size(*this, op_vector_type))
+       pointer_offset_size(expr_type, *this)==
+       pointer_offset_size(op_vector_type, *this))
     {
     }
     else
@@ -2415,6 +2415,7 @@ exprt c_typecheck_baset::do_special_functions(
   }
   else if(identifier==CPROVER_PREFIX "abs" ||
           identifier==CPROVER_PREFIX "labs" ||
+          identifier==CPROVER_PREFIX "llabs" ||
           identifier==CPROVER_PREFIX "fabs" ||
           identifier==CPROVER_PREFIX "fabsf" ||
           identifier==CPROVER_PREFIX "fabsl")
