@@ -148,7 +148,8 @@ void c_typecheck_baset::typecheck_type(typet &type)
 
       type=result;
     }
-    else if(underlying_type.id()==ID_c_enum_tag)
+    else if(underlying_type.id()==ID_c_enum_tag ||
+            underlying_type.id()==ID_complex)
     {
       // gcc allows this, but clang doesn't.
       // We ignore for now.
@@ -906,12 +907,14 @@ void c_typecheck_baset::typecheck_compound_body(symbolt &symbol)
     }  
   }
 
-  // we may add some minimal padding inside structs (not unions)
-  // unless there is an attribute that says that the struct is
-  // 'packed'
+  // We may add some minimal padding inside and at
+  // the end of structs and
+  // as additional member for unions.
 
   if(symbol.type.id()==ID_struct)
     add_padding(to_struct_type(symbol.type), *this);
+  else if(symbol.type.id()==ID_union)
+    add_padding(to_union_type(symbol.type), *this);
 
   // Now remove zero-width bit-fields, these are just
   // for adjusting alignment.
@@ -1148,8 +1151,14 @@ void c_typecheck_baset::typecheck_c_enum_type(typet &type)
     }
     else if(symbol.type.id()==ID_c_enum)
     {
-      err_location(type);
-      throw "redeclaration of enum tag";
+      // We might already have the same anonymous enum, and this is
+      // simply ok. Note that the C standard treats these as
+      // different types.
+      if(!base_name.empty())
+      {
+        err_location(type);
+        throw "redeclaration of enum tag";
+      }
     }
     else
     {
