@@ -11,8 +11,6 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/config.h>
 #include <util/replace_symbol.h>
 
-#include <linking/linking.h>
-
 #include "cprover_library.h"
 #include "ansi_c_language.h"
 
@@ -78,13 +76,10 @@ void add_cprover_library(
   {
     std::istringstream in(library_text.str());
     ansi_c_languaget ansi_c_language;
-    ansi_c_language.parse(in, "", message_handler);
-
-    symbol_tablet new_symbol_table;
-    ansi_c_language.typecheck(
-      new_symbol_table, "<built-in-library>", message_handler);
-
-    linking(symbol_table, new_symbol_table, message_handler);
+    ansi_c_language.set_message_handler(message_handler);
+    ansi_c_language.parse(in, "");
+    
+    ansi_c_language.typecheck(symbol_table, "<built-in-library>");
   }
 }
 
