@@ -9,13 +9,14 @@ Author: Daniel Kroening, kroening@kroening.com
 #ifndef CPROVER_STRING_CONSTANT_H
 #define CPROVER_STRING_CONSTANT_H
 
-#include <std_expr.h>
-#include <expr.h>
+#include <util/std_expr.h>
+#include <util/expr.h>
 
 class string_constantt:public exprt
 {
 public:
   string_constantt();
+  explicit string_constantt(const irep_idt &value);
 
   friend inline const string_constantt &to_string_constant(const exprt &expr)
   {
@@ -37,6 +38,7 @@ public:
   }
   
   array_exprt to_array_expr() const;
+  bool from_array_expr(const array_exprt &);
 };
 
 const string_constantt &to_string_constant(const exprt &expr);
