@@ -50,6 +50,7 @@ Function: bmct::do_unwind_module
 void bmct::do_unwind_module(
   decision_proceduret &decision_procedure)
 {
+  // this is a hook for hw-cbmc
 }
 
 /*******************************************************************\
@@ -133,15 +134,22 @@ Function: bmct::do_conversion
 
 void bmct::do_conversion(prop_convt &prop_conv)
 {
-  // convert HDL
+  // convert HDL (hook for hw-cbmc)
   do_unwind_module(prop_conv);
+  
+  status() << "converting SSA" << eom;
 
   // convert SSA
   equation.convert(prop_conv);
 
   // the 'extra constraints'
-  forall_expr_list(it, bmc_constraints)
-    prop_conv.set_to_true(*it);
+  if(!bmc_constraints.empty())
+  {
+    status() << "converting constraints" << eom;
+    
+    forall_expr_list(it, bmc_constraints)
+      prop_conv.set_to_true(*it);
+  }
 }
 
 /*******************************************************************\
@@ -458,31 +466,16 @@ bool bmct::run(const goto_functionst &goto_functions)
       return false;
     }
 
-    if(options.get_bool_option("all-properties"))
-    {
-      satcheckt satcheck;
-      satcheck.set_message_handler(get_message_handler());
-      bv_cbmct bv_cbmc(ns, satcheck);
-      bv_cbmc.set_message_handler(get_message_handler());
-
-      if(options.get_option("arrays-uf")=="never")
-        bv_cbmc.unbounded_array=bv_cbmct::U_NONE;
-      else if(options.get_option("arrays-uf")=="always")
-        bv_cbmc.unbounded_array=bv_cbmct::U_ALL;
-
-      return all_properties(goto_functions, bv_cbmc);
-    }
-    
     if(options.get_bool_option("smt1"))
-      return decide_smt1();
+      return decide_smt1(goto_functions);
     else if(options.get_bool_option("smt2"))
-      return decide_smt2();
+      return decide_smt2(goto_functions);
     else if(options.get_bool_option("dimacs"))
       return write_dimacs();
     else if(options.get_bool_option("refine"))
-      return decide_bv_refinement();
+      return decide_bv_refinement(goto_functions);
     else if(options.get_bool_option("aig"))
-      return decide_aig();
+      return decide_aig(goto_functions);
     else
     {
       if(options.get_bool_option("program-only"))
@@ -491,7 +484,7 @@ bool bmct::run(const goto_functionst &goto_functions)
         return false;
       }
 
-      return decide_default();
+      return decide_default(goto_functions);
     }
   }
 
@@ -526,14 +519,15 @@ Function: bmct::decide
 
 \*******************************************************************/
 
-bool bmct::decide(prop_convt &prop_conv)
+bool bmct::decide(
+  const goto_functionst &goto_functions,
+  prop_convt &prop_conv)
 {
-  if(options.get_bool_option("beautify-pbs") ||
-     options.get_bool_option("beautify-greedy"))
-    throw "sorry, this solver does not support beautification";
-
   prop_conv.set_message_handler(get_message_handler());
   
+  if(options.get_bool_option("all-properties"))
+    return all_properties(goto_functions, prop_conv);
+
   bool result=true;
 
   switch(run_decision_procedure(prop_conv))
