@@ -6,7 +6,7 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <util/location.h>
+#include <util/source_location.h>
 #include <util/std_types.h>
 
 #include <ansi-c/c_types.h>
@@ -31,7 +31,7 @@ cpp_declarator_convertert::cpp_declarator_convertert(
   class cpp_typecheckt &_cpp_typecheck):
   is_typedef(false),
   is_template(false),
-  is_template_argument(false),
+  is_template_parameter(false),
   is_friend(false),
   linkage_spec(_cpp_typecheck.current_linkage_spec),
   cpp_typecheck(_cpp_typecheck)
@@ -146,7 +146,7 @@ symbolt &cpp_declarator_convertert::convert(
 
     symbolt &symbol=c_it->second;
 
-    combine_types(declarator.name().location(), final_type, symbol);
+    combine_types(declarator.name().source_location(), final_type, symbol);
     enforce_rules(symbol);
 
     // If it is a constructor, we take care of the
@@ -164,7 +164,7 @@ symbolt &cpp_declarator_convertert::convert(
       if(symbol_expr.id()!=ID_type ||
          symbol_expr.type().id()!=ID_symbol)
       {
-        cpp_typecheck.err_location(name.location());
+        cpp_typecheck.err_location(name.source_location());
         cpp_typecheck.str << "error: expected type";
         throw 0;
       }
@@ -203,7 +203,7 @@ symbolt &cpp_declarator_convertert::convert(
     if(final_type.id()==ID_code &&
        to_code_type(final_type).return_type().id()==ID_constructor)
     {
-      cpp_typecheck.err_location(declarator.name().location());
+      cpp_typecheck.err_location(declarator.name().source_location());
       cpp_typecheck.str << "function must have return type";
       throw 0;
     }
@@ -223,7 +223,7 @@ symbolt &cpp_declarator_convertert::convert(
     if(declarator.get_bool("#template_case"))
       return symbol;
 
-    combine_types(declarator.name().location(), final_type, symbol);
+    combine_types(declarator.name().source_location(), final_type, symbol);
     enforce_rules(symbol);
 
     // initializer?
@@ -233,13 +233,13 @@ symbolt &cpp_declarator_convertert::convert(
     {
       cpp_scopet::id_sett id_set;
 
-      scope->lookup_identifier(symbol.name, cpp_idt::TEMPLATE_ARGUMENT, id_set);
+      scope->lookup_identifier(symbol.name, cpp_idt::TEMPLATE_PARAMETER, id_set);
 
       if(id_set.empty())
       {
         cpp_idt &identifier=
           cpp_typecheck.cpp_scopes.put_into_scope(symbol,*scope);
-        identifier.id_class=cpp_idt::TEMPLATE_ARGUMENT;
+        identifier.id_class=cpp_idt::TEMPLATE_PARAMETER;
       }
     }
 
@@ -260,7 +260,7 @@ Function: cpp_declarator_convertert::combine_types
 \*******************************************************************/
 
 void cpp_declarator_convertert::combine_types(
-  const locationt &location,
+  const source_locationt &source_location,
   const typet &decl_type,
   symbolt &symbol)
 {
@@ -289,7 +289,7 @@ void cpp_declarator_convertert::combine_types(
           // The 'this' parameter of virtual functions mismatches
           if(i!=0 || !symbol_code_type.get_bool("#is_virtual"))
           {
-            cpp_typecheck.err_location(location);
+            cpp_typecheck.err_location(source_location);
             cpp_typecheck.str << "symbol `" << symbol.display_name()
                               << "': parameter " << (i+1) << " type mismatch"
                               << std::endl;
@@ -305,7 +305,7 @@ void cpp_declarator_convertert::combine_types(
         {
           symbol_parameter.set_base_name(decl_parameter.get_base_name());
           symbol_parameter.set_identifier(decl_parameter.get_identifier());
-          symbol_parameter.location()=decl_parameter.location();
+          symbol_parameter.add_source_location()=decl_parameter.source_location();
         }
       }
 
@@ -324,7 +324,7 @@ void cpp_declarator_convertert::combine_types(
     return; // ok
   }
 
-  cpp_typecheck.err_location(location);
+  cpp_typecheck.err_location(source_location);
   cpp_typecheck.str << "symbol `" << symbol.display_name()
                     << "' already declared with different type:"
                     << std::endl;
@@ -456,7 +456,7 @@ void cpp_declarator_convertert::get_final_identifier()
       // Is there already an `extern "C"' function with the same name
       // and the same signature?
       symbol_tablet::symbolst::const_iterator
-        c_it=cpp_typecheck.symbol_table.symbols.find("c::"+identifier);
+        c_it=cpp_typecheck.symbol_table.symbols.find(identifier);
         
       if(c_it!=cpp_typecheck.symbol_table.symbols.end() &&
          c_it->second.type.id()==ID_code &&
@@ -474,7 +474,6 @@ void cpp_declarator_convertert::get_final_identifier()
   }
 
   final_identifier=
-    "c::"+
     scope->prefix+
     identifier;
 }
@@ -503,12 +502,12 @@ symbolt &cpp_declarator_convertert::convert_new_symbol(
   symbol.name=final_identifier;
   symbol.base_name=base_name;
   symbol.value=declarator.value();
-  symbol.location=declarator.name().location();
+  symbol.location=declarator.name().source_location();
   symbol.mode=linkage_spec==ID_auto?ID_cpp:linkage_spec;
   symbol.module=cpp_typecheck.module;
   symbol.type=final_type;
   symbol.is_type=is_typedef;
-  symbol.is_macro=is_typedef && !is_template_argument;
+  symbol.is_macro=is_typedef && !is_template_parameter;
   symbol.pretty_name=pretty_name;
   
   // Constant? These are propagated.
@@ -599,8 +598,8 @@ symbolt &cpp_declarator_convertert::convert_new_symbol(
 
   if(is_template)
     identifier.id_class=cpp_idt::TEMPLATE;
-  else if(is_template_argument)
-    identifier.id_class=cpp_idt::TEMPLATE_ARGUMENT;
+  else if(is_template_parameter)
+    identifier.id_class=cpp_idt::TEMPLATE_PARAMETER;
   else if(is_typedef)
     identifier.id_class=cpp_idt::TYPEDEF;
   else
@@ -693,7 +692,7 @@ Function: cpp_declarator_convertert::main_function_rules
 void cpp_declarator_convertert::main_function_rules(
   const symbolt &symbol)
 {
-  if(symbol.name=="c::main")
+  if(symbol.name==ID_main)
   {
     if(symbol.type.id()!=ID_code)
     {
