@@ -97,7 +97,7 @@ public:
   bool cpp_is_pod(const typet &type) const;
 
   codet cpp_constructor(
-    const locationt &location,
+    const source_locationt &source_location,
     const exprt &object,
     const exprt::operandst &operands);
 
@@ -132,7 +132,7 @@ protected:
   //
   // Templates
   //
-  void salvage_default_parameters(
+  void salvage_default_arguments(
     const template_typet &old_type,
     template_typet &new_type);
 
@@ -168,14 +168,15 @@ protected:
     const typet &function_type);
 
   cpp_template_args_tct typecheck_template_args(
-    const locationt &location,
+    const source_locationt &source_location,
     const symbolt &template_symbol,
     const cpp_template_args_non_tct &template_args);
-    
+
+  // template instantiations    
   class instantiationt
   {
   public:
-    locationt location;
+    source_locationt source_location;
     irep_idt identifier;
     cpp_template_args_tct full_template_args;
   };
@@ -205,7 +206,7 @@ protected:
   };
   
   const symbolt &class_template_symbol(
-    const locationt &location,
+    const source_locationt &source_location,
     const symbolt &template_symbol,
     const cpp_template_args_tct &specialization_template_args,
     const cpp_template_args_tct &full_template_args);  
@@ -214,14 +215,14 @@ protected:
     const typet &type);
 
   const symbolt &instantiate_template(
-    const locationt &location,
+    const source_locationt &source_location,
     const symbolt &symbol,
     const cpp_template_args_tct &specialization_template_args,
     const cpp_template_args_tct &full_template_args,
     const typet &specialization=typet(ID_nil));
 
   void elaborate_class_template(
-    const locationt &location,
+    const source_locationt &source_location,
     const symbol_typet &type);
 
   unsigned template_counter;
@@ -249,9 +250,9 @@ protected:
     exprt &symbol_expr);
 
   void default_ctor(
-    const locationt& location,
+    const source_locationt &source_location,
     const irep_idt &base_name,
-    cpp_declarationt& ctor) const;
+    cpp_declarationt &ctor) const;
 
   void default_cpctor(
     const symbolt&, cpp_declarationt& cpctor) const;
@@ -276,7 +277,7 @@ protected:
     const struct_union_typet &struct_union_type);
 
   void full_member_initialization(
-    const struct_typet &struct_type,
+    const struct_union_typet &struct_union_type,
     irept &initializers);
 
   bool find_cpctor(const symbolt& symbol)const;
@@ -289,17 +290,17 @@ protected:
     irep_idt &identifier);
 
   bool get_component(
-      const locationt& location,
-      const exprt& object,
-      const irep_idt& component_name,
-      exprt& member);
+    const source_locationt &source_location,
+    const exprt& object,
+    const irep_idt& component_name,
+    exprt& member);
 
-  void new_temporary(const locationt &location,
+  void new_temporary(const source_locationt &source_location,
                      const typet &,
                      const exprt::operandst &ops,
                      exprt &temporary);
 
-  void new_temporary(const locationt &location,
+  void new_temporary(const source_locationt &source_location,
                      const typet &,
                      const exprt &op,
                      exprt &temporary);
@@ -417,12 +418,12 @@ protected:
   void zero_initializer(
     const exprt &object,
     const typet &type,
-    const locationt &location,
+    const source_locationt &source_location,
     exprt::operandst &ops);
 
   // code conversion
   virtual void typecheck_code(codet &code);
-  virtual void typecheck_catch(codet &code);
+  virtual void typecheck_try_catch(codet &code);
   virtual void typecheck_member_initializer(codet &code);
   virtual void typecheck_decl(codet &code);
   virtual void typecheck_block(codet &code);
@@ -433,7 +434,7 @@ protected:
   const struct_typet &this_struct_type();
 
   codet cpp_destructor(
-      const locationt &location,
+      const source_locationt &source_location,
       const typet &type,
       const exprt &object);
 
@@ -465,11 +466,11 @@ protected:
   void typecheck_expr_sizeof(exprt &expr);
   void typecheck_expr_delete(exprt &expr);
   void typecheck_expr_side_effect(side_effect_exprt &expr);
-  void typecheck_side_effect_assignment(exprt &expr);
+  void typecheck_side_effect_assignment(side_effect_exprt &expr);
   void typecheck_side_effect_inc_dec(side_effect_exprt &expr);
   void typecheck_expr_typecast(exprt &expr);
-  void typecheck_expr_index(exprt& expr);
-  void typecheck_expr_rel(exprt& expr);
+  void typecheck_expr_index(exprt &expr);
+  void typecheck_expr_rel(binary_relation_exprt &expr);
   void typecheck_expr_comma(exprt &expr);
 
   void typecheck_function_call_arguments(
