@@ -41,8 +41,7 @@ void cpp_typecheckt::convert_argument(
     parameter.set_base_name(identifier);
   }
 
-  identifier=language_prefix+
-             cpp_scopes.current_scope().prefix+
+  identifier=cpp_scopes.current_scope().prefix+
              id2string(identifier);
 
   parameter.set_identifier(identifier);
@@ -51,7 +50,7 @@ void cpp_typecheckt::convert_argument(
 
   symbol.name=identifier;
   symbol.base_name=parameter.get_base_name();
-  symbol.location=parameter.location();
+  symbol.location=parameter.source_location();
   symbol.mode=mode;
   symbol.module=module;
   symbol.type=parameter.type();
