@@ -6,8 +6,6 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 \*******************************************************************/
 
-#include <iostream>
-
 #include <util/expr_util.h>
 #include <util/i2string.h>
 #include <util/simplify_expr_class.h>
@@ -22,7 +20,7 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 /*******************************************************************\
 
-Function: cpp_typecheckt::salvage_default_parameters
+Function: cpp_typecheckt::salvage_default_arguments
 
   Inputs:
 
@@ -32,21 +30,21 @@ Function: cpp_typecheckt::salvage_default_parameters
 
 \*******************************************************************/
 
-void cpp_typecheckt::salvage_default_parameters(
+void cpp_typecheckt::salvage_default_arguments(
   const template_typet &old_type,
   template_typet &new_type)
 {
-  const template_typet::parameterst &old_parameters=old_type.parameters();
-  template_typet::parameterst &new_parameters=new_type.parameters();
+  const template_typet::template_parameterst &old_parameters=old_type.template_parameters();
+  template_typet::template_parameterst &new_parameters=new_type.template_parameters();
 
   for(unsigned i=0; i<new_parameters.size(); i++)
   {
     if(i<old_parameters.size() &&
-       old_parameters[i].has_default_parameter() &&
-       !new_parameters[i].has_default_parameter())
+       old_parameters[i].has_default_argument() &&
+       !new_parameters[i].has_default_argument())
     {
       // TODO! The default may depend on previous parameters!!
-      new_parameters[i].default_parameter()=old_parameters[i].default_parameter();
+      new_parameters[i].default_argument()=old_parameters[i].default_argument();
     }
   }
 }
@@ -112,13 +110,13 @@ void cpp_typecheckt::typecheck_class_template(
 
   if(cpp_name.is_nil())
   {
-    err_location(type.location());
+    err_location(type.source_location());
     throw "class templates must not be anonymous";
   }
 
   if(!cpp_name.is_simple_name())
   {
-    err_location(cpp_name.location());
+    err_location(cpp_name.source_location());
     throw "simple name expected as class template tag";
   }
 
@@ -147,7 +145,7 @@ void cpp_typecheckt::typecheck_class_template(
       const symbolt &previous=lookup((*id_set.begin())->identifier);
       if(previous.name!=symbol_name || id_set.size()>1)
       {
-        err_location(cpp_name.location());
+        err_location(cpp_name.source_location());
         str << "template declaration of `" << base_name.c_str()
             << " does not match previous declaration\n";
         str << "location of previous definition: " << previous.location;
@@ -174,7 +172,7 @@ void cpp_typecheckt::typecheck_class_template(
     // check if we have 2 bodies
     if(has_body && previous_has_body)
     {
-      err_location(cpp_name.location());
+      err_location(cpp_name.source_location());
       str << "template struct `" << base_name
           << "' defined previously" << std::endl;
       str << "location of previous definition: "
@@ -186,13 +184,13 @@ void cpp_typecheckt::typecheck_class_template(
     {
       // We replace the template!
       // We have to retain any default parameters from the previous declaration.
-      salvage_default_parameters(
+      salvage_default_arguments(
         previous_declaration.template_type(),
         declaration.template_type());
       
       previous_symbol->second.type.swap(declaration);
       
-      #if 1
+      #if 0
       std::cout << "*****\n";
       std::cout << *cpp_scopes.id_map[symbol_name];
       std::cout << "*****\n";
@@ -207,8 +205,8 @@ void cpp_typecheckt::typecheck_class_template(
     }
     else
     {
-      // just update any default parameters
-      salvage_default_parameters(
+      // just update any default arguments
+      salvage_default_arguments(
         declaration.template_type(),
         previous_declaration.template_type());
     }
@@ -223,7 +221,7 @@ void cpp_typecheckt::typecheck_class_template(
 
   symbol.name=symbol_name;
   symbol.base_name=base_name;
-  symbol.location=cpp_name.location();
+  symbol.location=cpp_name.source_location();
   symbol.mode=ID_cpp;
   symbol.module=module;
   symbol.type.swap(declaration);
@@ -310,7 +308,7 @@ void cpp_typecheckt::typecheck_function_template(
 
     if(has_value && previous_has_value)
     {
-      err_location(cpp_name.location());
+      err_location(cpp_name.source_location());
       str << "function template symbol `" << base_name
           << "' declared previously" << std::endl;
       str << "location of previous definition: "
@@ -332,7 +330,7 @@ void cpp_typecheckt::typecheck_function_template(
   symbolt symbol;
   symbol.name=symbol_name;
   symbol.base_name=base_name;
-  symbol.location=cpp_name.location();
+  symbol.location=cpp_name.source_location();
   symbol.mode=ID_cpp;
   symbol.module=module;
   symbol.value.make_nil();
@@ -432,7 +430,7 @@ void cpp_typecheckt::typecheck_class_template_member(
   }
   else if((*(id_set.begin()))->id_class!=cpp_idt::TEMPLATE)
   {
-    std::cerr << *(*id_set.begin()) << std::endl;
+    // std::cerr << *(*id_set.begin()) << std::endl;
     err_location(cpp_name);
     str << "class template `"
         << cpp_name.get_sub().front().get(ID_identifier)
@@ -498,7 +496,6 @@ std::string cpp_typecheckt::class_template_identifier(
   const cpp_template_args_non_tct &partial_specialization_args)
 {
   std::string identifier=
-    language_prefix+
     cpp_scopes.current_scope().prefix+
     "template."+id2string(base_name) + "<";
 
@@ -506,9 +503,9 @@ std::string cpp_typecheckt::class_template_identifier(
 
   // these are probably not needed -- templates
   // should be unique in a namespace
-  for(template_typet::parameterst::const_iterator
-      it=template_type.parameters().begin();
-      it!=template_type.parameters().end();
+  for(template_typet::template_parameterst::const_iterator
+      it=template_type.template_parameters().begin();
+      it!=template_type.template_parameters().end();
       it++)
   {
     if(counter!=0) identifier+=',';
@@ -534,6 +531,9 @@ std::string cpp_typecheckt::class_template_identifier(
         it++, counter++)
     {  
       if(counter!=0) identifier+=',';
+      
+      // These are not yet typechecked, as they may depend
+      // on unassigned template parameters.
 
       if(it->id()==ID_type || it->id()=="ambiguous")
         identifier+=cpp_type2name(it->type());
@@ -602,8 +602,8 @@ void cpp_typecheckt::convert_class_template_specialization(
 
   if(cpp_name.is_qualified())
   {
-    err_location(cpp_name.location());
-    str << "qualifiers not excpected here";
+    err_location(cpp_name.source_location());
+    str << "qualifiers not expected here";
     throw 0;
   }
   
@@ -613,7 +613,7 @@ void cpp_typecheckt::convert_class_template_specialization(
   {
     // currently we are more restrictive
     // than the standard
-    err_location(cpp_name.location());
+    err_location(cpp_name.source_location());
     str << "bad template-class-sepcialization name";                                                
     throw 0;
   }
@@ -653,7 +653,7 @@ void cpp_typecheckt::convert_class_template_specialization(
   // only one should be left
   if(id_set.empty())
   {
-    err_location(type.location());
+    err_location(type.source_location());
     str << "class template `" << base_name << "' not found";
     throw 0;
   }
@@ -684,14 +684,14 @@ void cpp_typecheckt::convert_class_template_specialization(
     // typecheck arguments -- these are for the 'primary' template!
     cpp_template_args_tct template_args_tc=
       typecheck_template_args(
-        declaration.location(),
+        declaration.source_location(),
         to_cpp_declaration(template_symbol.type).template_type(),
         template_args_non_tc);
     
     // Full specialization, i.e., template<>.
     // We instantiate.
     instantiate_template(
-      cpp_name.location(),
+      cpp_name.source_location(),
       template_symbol,
       template_args_tc,
       type);
@@ -700,19 +700,10 @@ void cpp_typecheckt::convert_class_template_specialization(
   #endif
   
   {
-    // partial -- we typecheck
+    // partial specialization -- we typecheck
     declaration.partial_specialization_args()=template_args_non_tc;
     declaration.set_specialization_of(template_symbol.name);
 
-    // We can't typecheck arguments yet, they are used
-    // for guessing later. But we can check the number.
-    if(template_args_non_tc.arguments().size()!=
-       to_cpp_declaration(template_symbol.type).template_type().parameters().size())
-    {
-      err_location(cpp_name.location());
-      throw "template specialization with wrong number of arguments";
-    }    
-    
     typecheck_class_template(declaration);
   }
 }
@@ -748,8 +739,8 @@ void cpp_typecheckt::convert_template_function_or_member_specialization(
 
   if(cpp_name.is_qualified())
   {
-    err_location(cpp_name.location());
-    str << "qualifiers not excpected here";
+    err_location(cpp_name.source_location());
+    str << "qualifiers not expected here";
     throw 0;
   }
   
@@ -767,7 +758,7 @@ void cpp_typecheckt::convert_template_function_or_member_specialization(
     {
       // currently we are more restrictive
       // than the standard
-      err_location(cpp_name.location());
+      err_location(cpp_name.source_location());
       str << "bad template-function-specialization name";
       throw 0;
     }
@@ -781,13 +772,13 @@ void cpp_typecheckt::convert_template_function_or_member_specialization(
 
     if(id_set.empty())
     {
-      err_location(cpp_name.location());
+      err_location(cpp_name.source_location());
       str << "template function `" << base_name << "' not found";
       throw 0;
     }
     else if(id_set.size()>1)
     {
-      err_location(cpp_name.location());
+      err_location(cpp_name.source_location());
       str << "template function `" << base_name << "' is ambiguous";
     }
     
@@ -796,7 +787,7 @@ void cpp_typecheckt::convert_template_function_or_member_specialization(
 
     cpp_template_args_tct template_args=
       typecheck_template_args(
-        declaration.location(),
+        declaration.source_location(),
         template_symbol,
         to_cpp_template_args_non_tc(cpp_name.get_sub()[1]));
 
@@ -806,7 +797,7 @@ void cpp_typecheckt::convert_template_function_or_member_specialization(
     specialization.swap(declarator);
 
     instantiate_template(
-      cpp_name.location(),
+      cpp_name.source_location(),
       template_symbol,
       template_args,
       template_args,
@@ -859,11 +850,12 @@ cpp_scopet &cpp_typecheckt::typecheck_template_parameters(
   cpp_scopes.go_to(template_scope);
 
   // put template parameters into this scope
-  template_typet::parameterst &parameters=type.parameters();
+  template_typet::template_parameterst &parameters=
+    type.template_parameters();
 
   unsigned anon_count=0;
 
-  for(template_typet::parameterst::iterator
+  for(template_typet::template_parameterst::iterator
       it=parameters.begin();
       it!=parameters.end();
       it++)
@@ -889,12 +881,56 @@ cpp_scopet &cpp_typecheckt::typecheck_template_parameters(
       declarator.name().get_sub().push_back(name);
     }
 
-    cpp_declarator_converter.is_typedef=declaration.get_bool(ID_is_type);
-    cpp_declarator_converter.is_template_argument=true;
+    #if 1
+    // The declarator needs to be just a name
+    if(declarator.name().get_sub().size()!=1 ||
+       declarator.name().get_sub().front().id()!=ID_name)
+    {
+      err_location(declaration);
+      throw "template parameter must be simple name";
+    }
+    
+    cpp_scopet &scope=cpp_scopes.current_scope();
+    
+    irep_idt base_name=declarator.name().get_sub().front().get(ID_identifier);
+    irep_idt identifier=scope.prefix+id2string(base_name);
+    
+    // add to scope
+    cpp_idt &id=scope.insert(base_name);
+    id.identifier=identifier;
+    id.id_class=cpp_idt::TEMPLATE_PARAMETER;
+    
+    // is it a type or not?
+    if(declaration.get_bool(ID_is_type))
+    {
+      parameter=exprt(ID_type, typet(ID_symbol));
+      parameter.type().set(ID_identifier, identifier);
+      parameter.type().add_source_location()=declaration.find_location();
+    }
+    else
+    {
+      // The type is not checked, as it might depend
+      // on earlier parameters.
+      typet type=declaration.type();
+      parameter=symbol_exprt(identifier, type);
+    }
 
-    // There might be a default type or value.
+    // There might be a default type or default value.
     // We store it for later, as it can't be typechecked now
-    // because of dependencies on earlier parameters!
+    // because of possible dependencies on earlier parameters!
+    if(declarator.value().is_not_nil())
+      parameter.add(ID_C_default_value)=declarator.value();
+    
+    #else    
+    // is it a type or not?
+    cpp_declarator_converter.is_typedef=declaration.get_bool(ID_is_type);
+
+    // say it a template parameter
+    cpp_declarator_converter.is_template_parameter=true;
+
+    // There might be a default type or default value.
+    // We store it for later, as it can't be typechecked now
+    // because of possible dependencies on earlier parameters!
     exprt default_value=declarator.value();
     declarator.value().make_nil();
 
@@ -905,7 +941,7 @@ cpp_scopet &cpp_typecheckt::typecheck_template_parameters(
     {
       parameter=exprt(ID_type, typet(ID_symbol));
       parameter.type().set(ID_identifier, symbol.name);
-      parameter.type().location()=declaration.find_location();
+      parameter.type().add_source_location()=declaration.find_location();
     }
     else
       parameter=symbol.symbol_expr();
@@ -914,7 +950,8 @@ cpp_scopet &cpp_typecheckt::typecheck_template_parameters(
     if(default_value.is_not_nil())
       parameter.add(ID_C_default_value)=default_value;
 
-    parameter.location()=declaration.find_location();
+    parameter.add_source_location()=declaration.find_location();
+    #endif
   }
 
   // continue without adding to the prefix
@@ -936,12 +973,12 @@ Function: cpp_typecheckt::typecheck_template_args
 \*******************************************************************/
 
 cpp_template_args_tct cpp_typecheckt::typecheck_template_args(
-  const locationt &location,
+  const source_locationt &source_location,
   const symbolt &template_symbol,
   const cpp_template_args_non_tct &template_args)
 {
   // old stuff
-  assert(template_args.id()!="already_typechecked");
+  assert(template_args.id()!=ID_already_typechecked);
 
   assert(template_symbol.type.get_bool(ID_is_template));
 
@@ -955,12 +992,12 @@ cpp_template_args_tct cpp_typecheckt::typecheck_template_args(
   cpp_template_args_tct::argumentst &args=
     result.arguments();
     
-  const template_typet::parameterst &parameters=
-    template_type.parameters();
+  const template_typet::template_parameterst &parameters=
+    template_type.template_parameters();
     
   if(parameters.size()<args.size())
   {
-    err_location(location);
+    err_location(source_location);
     str << "too many template arguments (expected "
         << parameters.size() << ", but got "
         << args.size() << ")";
@@ -971,7 +1008,7 @@ cpp_template_args_tct cpp_typecheckt::typecheck_template_args(
   template_mapt old_template_map;
   old_template_map=template_map;
 
-  // check for default parameters
+  // check for default arguments
   for(unsigned i=0; i<parameters.size(); i++)
   {
     const template_parametert &parameter=parameters[i];
@@ -979,17 +1016,17 @@ cpp_template_args_tct cpp_typecheckt::typecheck_template_args(
     
     if(i>=args.size())
     {
-      // Check for default parameter.
+      // Check for default argument for the parameter.
       // These may depend on previous arguments.
-      if(!parameter.has_default_parameter())
+      if(!parameter.has_default_argument())
       {
-        err_location(location);
+        err_location(source_location);
         str << "not enough template arguments (expected "
             << parameters.size() << ", but got " << args.size() << ")";
         throw 0;
       }
 
-      args.push_back(parameter.default_parameter());
+      args.push_back(parameter.default_argument());
       
       // these need to be typechecked in the scope of the template,
       // not in the current scope!
@@ -1036,13 +1073,28 @@ cpp_template_args_tct cpp_typecheckt::typecheck_template_args(
         arg.swap(e);
       }
 
+      typet type=parameter.type();
+
+      // First check the parameter type (might have ealier
+      // type parameters in it). Needs to be checked in scope
+      // of template.
+      {
+        cpp_save_scopet cpp_saved_scope(cpp_scopes);
+        cpp_idt *template_scope=cpp_scopes.id_map[template_symbol.name];
+        assert(template_scope!=NULL);
+        cpp_scopes.go_to(*template_scope);
+        typecheck_type(type);
+      }
+      
+      // Now check the argument to match that.
       typecheck_expr(arg);
       simplify(arg, *this);
-      implicit_typecast(arg, parameter.type());
+      implicit_typecast(arg, type);
     }
     
-    // set right away -- this is for the benefit of default
-    // parameters
+    // Set right away -- this is for the benefit of default
+    // arguments and later parameters whose type might
+    // depend on an earlier parameter.
     
     template_map.set(parameter, arg);
   }
@@ -1092,7 +1144,8 @@ void cpp_typecheckt::convert_template_declaration(
   // there are
   // 1) function templates
   // 2) class templates
-  // 3) members of class templates (static or methods)
+  // 3) template members of class templates (static or methods)
+  // 4) variable templates (C++14)
 
   if(declaration.is_class_template())
   {
@@ -1123,18 +1176,18 @@ void cpp_typecheckt::convert_template_declaration(
     typecheck_class_template(declaration);
     return;
   }
-  else // maybe function template, maybe class template member
+  else // maybe function template, maybe class template member, maye template variable
   {
     // there should be declarators in either case
     if(declaration.declarators().empty())
     {
       err_location(declaration);
-      throw "function template or class template member expected to have declarator";
+      throw "non-class template is expected to have a declarator";
     }
 
     // Is it function template specialization?
     // Only full specialization is allowed!
-    if(declaration.template_type().parameters().empty())
+    if(declaration.template_type().template_parameters().empty())
     {
       convert_template_function_or_member_specialization(declaration);
       return;
