@@ -58,7 +58,7 @@ protected:
     const typet &type,
     const std::string &suffix,
     goto_programt &dest,
-    const locationt &location);
+    const source_locationt &);
   
   symbol_exprt make_compound_literal(
     const exprt &expr,
@@ -199,11 +199,11 @@ protected:
   void convert_msc_try_finally(const codet &code, goto_programt &dest);
   void convert_msc_try_except(const codet &code, goto_programt &dest);
   void convert_msc_leave(const codet &code, goto_programt &dest);
-  void convert_catch(const codet &code, goto_programt &dest);
+  void convert_try_catch(const codet &code, goto_programt &dest);
   void convert_CPROVER_try_catch(const codet &code, goto_programt &dest);
   void convert_CPROVER_try_finally(const codet &code, goto_programt &dest);
   void convert_CPROVER_throw(const codet &code, goto_programt &dest);
-  void convert_asm(const codet &code, goto_programt &dest);
+  void convert_asm(const code_asmt &code, goto_programt &dest);
 
   void convert(const codet &code, goto_programt &dest);
 
@@ -215,8 +215,8 @@ protected:
   
   symbol_exprt exception_flag();
   void unwind_destructor_stack(
-    const locationt &location,
-    unsigned stack_size,
+    const source_locationt &,
+    std::size_t stack_size,
     goto_programt &dest,
     bool do_dead=true);
 
@@ -354,7 +354,7 @@ protected:
     goto_programt::targett break_target;
     goto_programt::targett default_target;
     bool break_set, default_set;  
-    unsigned break_stack_size;
+    std::size_t break_stack_size;
 
     casest cases;
     cases_mapt cases_map;
@@ -379,7 +379,7 @@ protected:
 
     goto_programt::targett throw_target;
     bool throw_set;
-    unsigned throw_stack_size;
+    std::size_t throw_stack_size;
   };
   
   struct leave_targett
@@ -401,7 +401,7 @@ protected:
 
     goto_programt::targett leave_target;
     bool leave_set;
-    unsigned leave_stack_size;
+    std::size_t leave_stack_size;
   };
   
   void case_guard(
@@ -414,7 +414,7 @@ protected:
     const exprt &cond,
     goto_programt &true_case,
     goto_programt &false_case,
-    const locationt &location,
+    const source_locationt &,
     goto_programt &dest);
 
   // if(guard) goto target_true; else goto target_false;
@@ -422,14 +422,14 @@ protected:
     const exprt &guard,
     goto_programt::targett target_true,
     goto_programt::targett target_false,
-    const locationt &location,
+    const source_locationt &,
     goto_programt &dest);
 
   // if(guard) goto target;
   void generate_conditional_branch(
     const exprt &guard,
     goto_programt::targett target_true,
-    const locationt &location,
+    const source_locationt &,
     goto_programt &dest);
     
   // turn a OP b OP c into a list a, b, c
