@@ -7,6 +7,8 @@ Author: Daniel Kroening, kroening@kroening.com
 \*******************************************************************/
 
 #include <util/std_types.h>
+#include <util/cprover_prefix.h>
+
 #include <ansi-c/c_types.h>
 
 #include "java_bytecode_internal_additions.h"
@@ -25,13 +27,13 @@ Function: java_internal_additions
 
 void java_internal_additions(symbol_tablet &dest)
 {
-  // add c::__CPROVER_rounding_mode
+  // add __CPROVER_rounding_mode
 
   {
     symbolt symbol;
     symbol.base_name="__CPROVER_rounding_mode";
-    symbol.name="c::__CPROVER_rounding_mode";
-    symbol.type=int_type();
+    symbol.name=CPROVER_PREFIX "rounding_mode";
+    symbol.type=signed_int_type();
     symbol.mode=ID_C;
     symbol.is_lvalue=true;
     symbol.is_state_var=true;
