@@ -117,7 +117,7 @@ protected:
   {
     // follow a #number
     assert(!ref.empty() && ref[0]=='#');
-    return constants[unsafe_str2unsigned(ref.c_str()+1)].value_string;
+    return constants[unsafe_c_str2unsigned(ref.c_str()+1)].value_string;
   }
   
   typedef std::map<unsigned, unsigned> address_to_linet;
@@ -173,7 +173,7 @@ bool javap_parsert::parse()
   
   catch(const parsing_errort &p)
   {
-    error(p.msg);
+    error() << p.msg << eom;
     return true;
   }
   
@@ -265,7 +265,7 @@ void javap_parsert::rcompiled_from()
   std::string s="Compiled from \"";
   if(std::string(line, 0, s.size())!=s)
     throw parsing_errort("Expected 'Compiled from'");
-  location.set_file(std::string(line, s.size(), line.size()-s.size()-1));
+  source_location.set_file(std::string(line, s.size(), line.size()-s.size()-1));
 }
 
 /*******************************************************************\
@@ -466,8 +466,8 @@ void javap_parsert::rcode(membert &dest_member)
   // do we have a line number?
   if(address_to_line.find(instruction.address)!=address_to_line.end())
   {
-    instruction.location.set_line(address_to_line[instruction.address]);
-    instruction.location.set_file(location.get_file());
+    instruction.source_location.set_line(address_to_line[instruction.address]);
+    instruction.source_location.set_file(source_location.get_file());
   }
 }
 
@@ -790,7 +790,7 @@ bool javap_parse(
   {
     std::ifstream stderr_stream(stderr_file.c_str());
     char ch;
-    while((stderr_stream.read(&ch, 1))!=0)
+    while(stderr_stream.read(&ch, 1))
       message_stream.str << ch;
   }
 
