@@ -182,7 +182,7 @@ void value_set_fivrt::output(
       
       if (vr != object_map.read().validity_ranges.end())
       {
-        if (vr->second.size()==0)
+        if (vr->second.empty())
           std::cout << "        Empty validity record" << std::endl;
         else
           for (object_map_dt::vrange_listt::const_iterator vit =
@@ -717,8 +717,7 @@ void value_set_fivrt::get_value_set_rec(
     
     return;
   }
-  else if(expr.id()==ID_dereference ||
-          expr.id()=="implicit_dereference")
+  else if(expr.id()==ID_dereference)
   {
     object_mapt reference_set;
     get_reference_set_sharing(expr, reference_set, ns);
@@ -1073,8 +1072,7 @@ void value_set_fivrt::get_reference_set_sharing_rec(
 
     return;
   }
-  else if(expr.id()==ID_dereference ||
-          expr.id()=="implicit_dereference")
+  else if(expr.id()==ID_dereference)
   {
     if(expr.operands().size()!=1)
       throw expr.id_string()+" expected to have one operand";
@@ -1604,8 +1602,7 @@ void value_set_fivrt::assign_rec(
     
     make_union(temp_entry.object_map, values_rhs);
   }
-  else if(lhs.id()==ID_dereference ||
-          lhs.id()=="implicit_dereference")
+  else if(lhs.id()==ID_dereference)
   {
     if(lhs.operands().size()!=1)
       throw lhs.id_string()+" expected to have one operand";
