@@ -182,7 +182,7 @@ void value_set_fivrnst::output_entry(
     
     if (vr != object_map.read().validity_ranges.end())
     {
-      if (vr->second.size()==0)
+      if (vr->second.empty())
         std::cout << "        Empty validity record" << std::endl;
       else
         for (object_map_dt::vrange_listt::const_iterator vit =
@@ -491,8 +491,7 @@ void value_set_fivrnst::get_value_set_rec(
     
     return;
   }
-  else if(expr.id()==ID_dereference ||
-          expr.id()=="implicit_dereference")
+  else if(expr.id()==ID_dereference)
   {
     object_mapt reference_set;
     get_reference_set(expr, reference_set, ns);
@@ -776,8 +775,7 @@ void value_set_fivrnst::get_reference_set_rec(
 
     return;
   }
-  else if(expr.id()==ID_dereference ||
-          expr.id()=="implicit_dereference")
+  else if(expr.id()==ID_dereference)
   {
     if(expr.operands().size()!=1)
       throw expr.id_string()+" expected to have one operand";
@@ -1235,8 +1233,7 @@ void value_set_fivrnst::assign_rec(
     
     make_union(temp_entry.object_map, values_rhs);
   }
-  else if(lhs.id()==ID_dereference ||
-          lhs.id()=="implicit_dereference")
+  else if(lhs.id()==ID_dereference)
   {
     if(lhs.operands().size()!=1)
       throw lhs.id_string()+" expected to have one operand";
