@@ -54,7 +54,6 @@ Function: arrayst::record_array_index
 void arrayst::record_array_index(const index_exprt &index)
 {
   std::size_t number=arrays.number(index.array());
-  if(number>=index_map.size()) index_map.resize(number+1);
   index_map[number].insert(index.index());
 }
 
@@ -222,6 +221,12 @@ void arrayst::collect_arrays(const exprt &a)
     else
       throw "unexpected array type cast from "+a.op0().type().id_string();
   }
+  else if(a.id()==ID_index)
+  {
+    // nested unbounded arrays
+    arrays.make_union(a, a.op0());
+    collect_arrays(a.op0());
+  }
   else
     throw "unexpected array expression (collect_arrays): `"+a.id_string()+"'";
 }
@@ -245,9 +250,15 @@ void arrayst::add_array_constraints()
   
   // add constraints for if, with, array_of
   for(std::size_t i=0; i<arrays.size(); i++)
-    add_array_constraints(
-      index_map[arrays.find_number(i)],
-      arrays[i]);
+  {
+    update_index_map();
+
+    // take a copy as arrays may get modified by add_array_constraints
+    // in case of nested unbounded arrays
+    exprt a=arrays[i];
+
+    add_array_constraints(index_map[arrays.find_number(i)], a);
+  }
 
   // add constraints for equalities
   for(array_equalitiest::const_iterator it=
@@ -322,11 +333,7 @@ void arrayst::add_array_Ackermann_constraints()
           
             equal_exprt values_equal(index_expr1, index_expr2);
 
-            bvt implication;
-            implication.reserve(2);
-            implication.push_back(prop.lnot(indices_equal_lit));
-            implication.push_back(convert(values_equal));
-            prop.lcnf(implication);
+            prop.lcnf(!indices_equal_lit, convert(values_equal));
           }
         }
   }
@@ -348,9 +355,6 @@ void arrayst::build_index_map()
 {
   // merge the indices into the root
   
-  if(index_map.size()<arrays.size())
-    index_map.resize(arrays.size());
-
   // iterate over non-roots
   for(std::size_t i=0; i<arrays.size(); i++)
   {
@@ -368,6 +372,39 @@ void arrayst::build_index_map()
 
 /*******************************************************************\
 
+Function: arrayst::update_index_map
+
+  Inputs:
+
+ Outputs:
+
+ Purpose:
+
+\*******************************************************************/
+
+void arrayst::update_index_map()
+{
+  // merge the indices into the root
+  
+  const unsigned size_before=index_map.size();
+
+  // iterate over non-roots
+  for(unsigned i=size_before; i<arrays.size(); i++)
+  {
+    if(arrays.is_root_number(i)) continue;
+
+    unsigned root_number=arrays.find_number(i);
+    assert(root_number!=i);
+
+    index_sett &root_index_set=index_map[root_number];
+    index_sett &index_set=index_map[i];
+
+    root_index_set.insert(index_set.begin(), index_set.end());
+  }
+}
+
+/*******************************************************************\
+
 Function: arrayst::add_array_constraints
 
   Inputs:
@@ -404,10 +441,7 @@ void arrayst::add_array_constraints(
     equal_exprt equality_expr(index_expr1, index_expr2);
     
     // add constraint
-    bvt bv;
-    bv.push_back(prop.lnot(array_equality.l));
-    bv.push_back(convert(equality_expr));
-    prop.lcnf(bv);
+    prop.lcnf(!array_equality.l, convert(equality_expr));
   }
 }  
 
@@ -479,6 +513,9 @@ void arrayst::add_array_constraints(
       set_to(equal_exprt(index_expr1, index_expr2), true);
     }
   }
+  else if(expr.id()==ID_index)
+  {
+  }
   else
     throw "unexpected array expression (add_array_constraints): `"+expr.id_string()+"'";
 }
@@ -735,10 +772,7 @@ void arrayst::add_array_constraints_if(
     assert(index_expr1.type()==index_expr2.type());
 
     // add implication
-    bvt bv;
-    bv.push_back(prop.lnot(cond_lit));
-    bv.push_back(convert(equal_exprt(index_expr1, index_expr2)));
-    prop.lcnf(bv);
+    prop.lcnf(!cond_lit, convert(equal_exprt(index_expr1, index_expr2)));
   }
 
   // now the false case
@@ -761,9 +795,6 @@ void arrayst::add_array_constraints_if(
     assert(index_expr1.type()==index_expr2.type());
 
     // add implication
-    bvt bv;
-    bv.push_back(cond_lit);
-    bv.push_back(convert(equal_exprt(index_expr1, index_expr2)));
-    prop.lcnf(bv);
+    prop.lcnf(cond_lit, convert(equal_exprt(index_expr1, index_expr2)));
   }
 }
