@@ -337,6 +337,11 @@ void boolbvt::convert_bitvector(const exprt &expr, bvt &bv)
     return convert_lambda(expr, bv);
   else if(expr.id()==ID_array_of)
     return convert_array_of(to_array_of_expr(expr), bv);
+  else if(expr.id()==ID_let)
+  {
+    //const let_exprt &let_expr=to_let_expr(expr);
+    throw "let is todo";
+  }
   else if(expr.id()==ID_function_application)
   {
     // make it free bits
@@ -514,6 +519,9 @@ literalt boolbvt::convert_rest(const exprt &expr)
     return convert_typecast(expr);
   else if(expr.id()==ID_equal)
     return convert_equality(to_equal_expr(expr));
+  else if(expr.id()==ID_verilog_case_equality ||
+          expr.id()==ID_verilog_case_inequality)
+    return convert_verilog_case_equality(to_binary_relation_expr(expr));
   else if(expr.id()==ID_notequal)
   {
     if(expr.operands().size()!=2)
