@@ -20,7 +20,7 @@ Function: boolbvt::convert_constant
 
 \*******************************************************************/
 
-void boolbvt::convert_constant(const exprt &expr, bvt &bv)
+void boolbvt::convert_constant(const constant_exprt &expr, bvt &bv)
 {
   unsigned width=boolbv_width(expr.type());
   
@@ -29,7 +29,9 @@ void boolbvt::convert_constant(const exprt &expr, bvt &bv)
 
   bv.resize(width);
   
-  if(expr.type().id()==ID_array)
+  const typet &expr_type=expr.type();
+  
+  if(expr_type.id()==ID_array)
   {
     unsigned op_width=width/expr.operands().size();
     unsigned offset=0;
@@ -49,10 +51,10 @@ void boolbvt::convert_constant(const exprt &expr, bvt &bv)
     
     return;
   }
-  else if(expr.type().id()==ID_range)
+  else if(expr_type.id()==ID_range)
   {
-    mp_integer from=string2integer(expr.type().get_string(ID_from));
-    mp_integer value=string2integer(expr.get_string(ID_value));
+    mp_integer from=to_range_type(expr_type).get_from();
+    mp_integer value=string2integer(id2string(expr.get_value()));
     mp_integer v=value-from;
     
     std::string binary=integer2binary(v, width);
@@ -65,28 +67,18 @@ void boolbvt::convert_constant(const exprt &expr, bvt &bv)
 
     return;
   }
-  else if(expr.type().id()==ID_c_enum ||
-          expr.type().id()==ID_incomplete_c_enum)
+  else if(expr_type.id()==ID_unsignedbv ||
+          expr_type.id()==ID_signedbv ||
+          expr_type.id()==ID_bv ||
+          expr_type.id()==ID_fixedbv ||
+          expr_type.id()==ID_floatbv ||
+          expr_type.id()==ID_c_enum ||
+          expr_type.id()==ID_c_enum_tag ||
+          expr_type.id()==ID_c_bool ||
+          expr_type.id()==ID_c_bit_field ||
+          expr_type.id()==ID_incomplete_c_enum)
   {
-    mp_integer value=string2integer(expr.get_string(ID_value));
-    std::string binary=integer2binary(value, width);
-    assert(width!=0);
-
-    for(unsigned i=0; i<width; i++)
-    {
-      bool bit=(binary[binary.size()-i-1]=='1');
-      bv[i]=const_literal(bit);
-    }
-
-    return;
-  }
-  else if(expr.type().id()==ID_unsignedbv ||
-          expr.type().id()==ID_signedbv ||
-          expr.type().id()==ID_bv ||
-          expr.type().id()==ID_fixedbv ||
-          expr.type().id()==ID_floatbv)
-  {
-    const std::string &binary=expr.get_string(ID_value);
+    const std::string &binary=id2string(expr.get_value());
 
     if(binary.size()!=width)
       throw "wrong value length in constant: "+expr.to_string();
@@ -99,9 +91,9 @@ void boolbvt::convert_constant(const exprt &expr, bvt &bv)
 
     return;
   }
-  else if(expr.type().id()==ID_verilogbv)
+  else if(expr_type.id()==ID_verilogbv)
   {
-    const std::string &binary=expr.get_string(ID_value);
+    const std::string &binary=id2string(expr.get_value());
 
     if(binary.size()*2!=width)
       throw "wrong value length in constant: "+expr.to_string();
