@@ -10,13 +10,15 @@ Author: Daniel Kroening, kroening@kroening.com
 #define CPROVER_PROPDEC_LITERAL_H
 
 #include <vector>
-#include <ostream>
+#include <iosfwd>
 
 // a pair of a variable number and a sign, encoded as follows:
 //
 // sign='false' means positive
 // sign='true' means negative
 //
+// The top bit is used to indicate that the literal is constant
+// true or false.
 
 class literalt
 {
@@ -102,8 +104,8 @@ public:
   }
 
   //
-  // Returns a literal in the dimacs CNF encoding
-  // A negative integer denotes a negated literal
+  // Returns a literal in the dimacs CNF encoding.
+  // A negative integer denotes a negated literal.
   //
   int dimacs() const
   {
@@ -177,13 +179,13 @@ public:
   }
   
 protected:
+  // We deliberately don't use size_t here to save some memory
+  // on 64-bit machines; i.e., in practice, we restrict ourselves
+  // to SAT instances with no more than 2^31 variables.
   unsigned l;  
 };
 
-static inline std::ostream & operator << (std::ostream &out, literalt l)
-{
-  return out << (l.sign()?"-":"") << l.var_no();
-}
+std::ostream & operator << (std::ostream &out, literalt l);
 
 // constants
 literalt const_literal(bool value);
