@@ -421,7 +421,7 @@ void smt1_convt::convert_address_of_rec(
       const irep_idt &component_name=
         member_expr.get_component_name();
 
-      mp_integer offset=member_offset(ns, struct_type, component_name);
+      mp_integer offset=member_offset(struct_type, component_name, ns);
 
       typet index_type(ID_unsignedbv);
       index_type.set(ID_width, boolbv_width(result_type));
@@ -2310,7 +2310,7 @@ void smt1_convt::convert_plus(const plus_exprt &expr)
         throw "unexpected mixture in pointer arithmetic";
 
       mp_integer element_size=
-        pointer_offset_size(ns, expr.type().subtype());
+        pointer_offset_size(expr.type().subtype(), ns);
         
       // adjust width if needed    
       if(boolbv_width(i.type())!=boolbv_width(expr.type()))
