@@ -9,7 +9,8 @@ Author: Daniel Kroening, kroening@kroening.com
 #ifndef CPROVER_INTERVAL_H
 #define CPROVER_INTERVAL_H
 
-#include <ostream>
+#include <algorithm>
+#include <iosfwd>
 
 #include "threeval.h"
 
