@@ -22,7 +22,7 @@ public:
   message_streamt(message_handlert &_message_handler):
     message_clientt(_message_handler),
     error_found(false),
-    saved_error_location(static_cast<const locationt &>(get_nil_irep())),
+    saved_error_location(static_cast<const source_locationt &>(get_nil_irep())),
     sequence_number(1)
   {
   }
@@ -33,10 +33,10 @@ public:
   virtual std::string to_string(const exprt &expr) { return expr.to_string(); }
   virtual std::string to_string(const typet &type) { return type.to_string(); }
 
-  void err_location(const exprt &expr) { saved_error_location=expr.find_location(); }
-  void err_location(const typet &type) { saved_error_location=type.location(); }
-  void err_location(const irept &irep) { saved_error_location=(const locationt &)irep.find("#location"); }
-  void err_location(const locationt &_location) { saved_error_location=_location; }
+  void err_location(const exprt &expr) { saved_error_location=expr.find_source_location(); }
+  void err_location(const typet &type) { saved_error_location=type.source_location(); }
+  void err_location(const irept &irep) { saved_error_location=static_cast<const source_locationt &>(irep.find(ID_C_source_location)); }
+  void err_location(const source_locationt &_location) { saved_error_location=_location; }
 
   void error(const std::string &message)
   {
@@ -107,7 +107,7 @@ public:
 
 protected:
   bool error_found;  
-  locationt saved_error_location;
+  source_locationt saved_error_location;
   unsigned sequence_number;
   
   void send_msg(unsigned level, const std::string &message)
