@@ -921,6 +921,7 @@ inline const bitvector_typet &to_bitvector_type(const typet &type)
          type.id()==ID_unsignedbv ||
          type.id()==ID_fixedbv ||
          type.id()==ID_floatbv ||
+         type.id()==ID_verilogbv ||
          type.id()==ID_bv ||
          type.id()==ID_pointer ||
          type.id()==ID_c_bit_field ||
@@ -986,6 +987,7 @@ public:
   mp_integer smallest() const;
   mp_integer largest() const;
   constant_exprt smallest_expr() const;
+  constant_exprt zero_expr() const;
   constant_exprt largest_expr() const;
 };
 
@@ -1031,6 +1033,7 @@ public:
   mp_integer smallest() const;
   mp_integer largest() const;
   constant_exprt smallest_expr() const;
+  constant_exprt zero_expr() const;
   constant_exprt largest_expr() const;
 };
 
